---
title: <span class="badge builder"></span> ExprTypeThresholdConditions
---
# <span class="badge builder"></span> ExprTypeThresholdConditions

## Constructor

```python
ExprTypeThresholdConditions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> expr.ExprTypeThresholdConditions
```

### <span class="badge object-method"></span> evaluator

```python
def evaluator(evaluator: cogbuilder.Builder[expr.ExprTypeThresholdConditionsEvaluator]) -> typing.Self
```

### <span class="badge object-method"></span> loaded_dimensions

```python
def loaded_dimensions(loaded_dimensions: object) -> typing.Self
```

### <span class="badge object-method"></span> unload_evaluator

```python
def unload_evaluator(unload_evaluator: cogbuilder.Builder[expr.ExprTypeThresholdConditionsUnloadEvaluator]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ExprTypeThresholdConditions](./object-ExprTypeThresholdConditions.md)
